@@ -45,13 +45,15 @@ from whatap.conf.configure import Configure as conf
 CONFIG_FILE_NAME = 'whatap.conf'
 LOG_FILE_NAME = 'whatap-hook.log'
 
-isFrappeCommands = "get-frappe-commands" in sys.argv
+isFrappeCommands = "get-frappe-commands" in sys.argv if hasattr(sys, "argv") else False
 
 def whatap_print(*args):
     if isFrappeCommands:
         logging.info(*args)
     else:
-        print(*args)
+        if len(args) > 0:
+            message = " ".join(args)
+            print(message)
 
 class Logger(object):
     def __init__(self):
@@ -191,7 +193,6 @@ def init_config(home):
 def update_config(home, opt_key, opt_value):
     config_file = os.path.join(os.environ[home],
                                CONFIG_FILE_NAME)
-    
     try:
         with open(config_file, 'r+') as f:
             is_update = False
@@ -205,7 +206,7 @@ def update_config(home, opt_key, opt_value):
                     
                     content += line
             if not is_update:
-                content += '{0}={1}\n'.format(opt_key, opt_value)
+                content += '\n{0}={1}\n'.format(opt_key, opt_value)
             open(config_file, 'w+').write(content)
     
     except Exception as e:
@@ -370,7 +371,7 @@ def go(batch=False, opts={}):
         process = subprocess.Popen(['./{0}'.format(AGENT_NAME), '-t', '3', '-d', '1'],
                                    cwd=home_path,env=newenv, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         stdouts, errs = process.communicate()
-        whatap_print("executed golang module ", stdouts, errs)
+        whatap_print("executed golang module ", str(stdouts,"utf8"), str(errs, "utf8"))
     except Exception as e:
         import traceback
         traceback.print_exc()
